@@ -11,28 +11,27 @@ logger = logging.getLogger(__name__)
 
 
 def paths(
-        path, kind='file', status = "present",
-        permissions = None, uid = None, gid = None, **kwargs
-    ):
-    if kind == 'file':
-         _func = os.path.isfile
-    elif kind == 'directory':
+    path, kind="file", status="present", permissions=None, uid=None, gid=None, **kwargs
+):
+    if kind == "file":
+        _func = os.path.isfile
+    elif kind == "directory":
         _func = os.path.isdir
 
     try:
         exists = _func(path)
-    except FileNotFoundError as e:
-        if status != 'present':
+    except FileNotFoundError:
+        if status != "present":
             return True
         else:
             return False
 
     # existence
-    if exists and status == 'present':
+    if exists and status == "present":
         status = True
-    elif not exists and status == 'absent':
+    elif not exists and status == "absent":
         return True
-    elif not exists and status == 'present':
+    elif not exists and status == "present":
         return False
     else:
         raise NotImplemented()
@@ -49,11 +48,11 @@ def paths(
         return status
 
     # TODO: additional checks on atime, ctime, mtime are possible
-    if permissions and permissions != perms['permissions']:
+    if permissions and permissions != perms["permissions"]:
         return False
-    elif uid and uid != perms['user']:
+    elif uid and uid != perms["user"]:
         return False
-    elif gid and gid != perms['group']:
+    elif gid and gid != perms["group"]:
         return False
     else:
         return status
@@ -64,30 +63,31 @@ def get_permissions(path) -> dict:
     st = os.stat(path)
     perm = str(oct(st.st_mode))
     return {
-        'raw_permissions': perm,
-        'permissions': perm[4:],
-        'user': st.st_uid,
-        'group': st.st_gid,
-        'create': datetime.fromtimestamp(st.st_ctime),
-        'modified': datetime.fromtimestamp(st.st_mtime),
-        'last_access': datetime.fromtimestamp(st.st_atime)
+        "raw_permissions": perm,
+        "permissions": perm[4:],
+        "user": st.st_uid,
+        "group": st.st_gid,
+        "create": datetime.fromtimestamp(st.st_ctime),
+        "modified": datetime.fromtimestamp(st.st_mtime),
+        "last_access": datetime.fromtimestamp(st.st_atime),
     }
 
 
-def size(path, unit='MB', kind='free', operator='ge', value=100, **kwargs) -> int:
+def size(path, unit="MB", kind="free", operator="ge", value=100, **kwargs) -> int:
     """
-        kind = set(
-            total, used, free, percent
-        )
+    kind = set(
+        total, used, free, percent
+    )
     """
     size = psutil.disk_usage(path)
-    if kind == 'percent':
+    if kind == "percent":
         size = size.percent
     else:
-        size =  memory_conv(getattr(size, kind), unit)
+        size = memory_conv(getattr(size, kind), unit)
     value = float(value)
     logger.debug(f"Found {size}{unit} in {path}")
     return getattr(op, operator)(size, value)
 
+
 def current_working_directory(path, **kwargs):
     return path == os.getcwd()
